@@ -5,7 +5,7 @@ def get_ath_name(dbname):
     connection = sqlite3.connect(dbname)
     cursor = connection.cursor()
 
-    names = cursor.execute("""SELECT name FROM athletes""")
+    names = cursor.execute("SELECT name FROM athletes")
     names_list = [row[0] for row in names.fetchall()]
     names_json = json.dump(names_list)
 
